OC.L10N.register(
    "twofactor_nextcloud_notification",
    {
    "TwoFactor Nextcloud notification" : "TwoFactor Nextcloud通知",
    "Approve" : "承認",
    "Cancel" : "キャンセル",
    "Login attempt from IP address {ip}" : "IPアドレス{ip}からのログイン試行",
    "If you are currently trying log in from another device or browser please approve the request. If you are not trying to log in at the moment, you should use the cancel option to abort the login attempt." : "別のデバイスまたはブラウザからログインしようとしている場合は、要求を承認してください。現在ログインしようとしていない場合は、cancelオプションを使用してログイン試行を中止してください。",
    "Nextcloud Notification" : "Nextcloud通知",
    "Authenticate using a device that is already logged in to your account" : "すでにアカウントにログインしている端末を使用して認証する",
    "Two-Factor Authentication via Nextcloud notification" : "Nextcloudの通知経由での二要素認証",
    "Allows using any of your logged in devices as second factor" : "ログインしたデバイスのいずれかを第2因子として使用できます",
    "Please accept the request on one of your logged in devices." : "ログインしているデバイスの1つでリクエストを承認してください。",
    "You will be redirected automatically once this login has been accepted." : "このログインが承認されると自動的にリダイレクトされます。",
    "Please wait …" : "しばらくお待ちください…",
    "Your login attempt was rejected." : "ログイン要求に失敗しました",
    "Use two-factor authentication via Nextcloud notifications" : "Nextcloud通知による二要素認証の使用"
},
"nplurals=1; plural=0;");
